from setuptools import setup, find_packages

setup(
    name='gemini_assistant',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'google-genai',  # The dependency for Google's Gemini API
    ],
    author='Farsan Suneer',
    author_email='farsansuneer@gmail.com',
    description='A helper library for integrating the Google Gemini API into web applications.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/fars-a/gemini_assistant',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.8',
)